import * as aws from 'aws-sdk';
import { Message } from 'aws-sdk/clients/sqs';
export interface SqsConsumerOptions {
    queueUrl: string;
    region?: string;
    batchSize?: number;
    waitTimeSeconds?: number;
    getPayloadFromS3?: boolean;
    sqs?: aws.SQS;
    s3?: aws.S3;
    sqsEndpointUrl?: string;
    s3EndpointUrl?: string;
    handleMessage?(message: SqsMessage): Promise<void>;
    parsePayload?(payload: any): any;
    transformMessageBody?(messageBody: any): any;
}
export declare enum SqsConsumerEvents {
    started = "started",
    messageReceived = "message-received",
    messageParsed = "message-parsed",
    messageProcessed = "message-processed",
    stopped = "stopped",
    error = "error",
    s3PayloadError = "s3-payload-error",
    processingError = "processing-error",
    connectionError = "connection-error",
    payloadParseError = "payload-parse-error"
}
interface SqsMessage {
    payload: any;
    message: Message;
}
export declare class SqsConsumer {
    private sqs;
    private s3;
    private queueUrl;
    private getPayloadFromS3;
    private batchSize;
    private waitTimeSeconds;
    private started;
    private events;
    private connErrorTimeout;
    private handleMessage?;
    private parsePayload?;
    private transformMessageBody?;
    constructor(options: SqsConsumerOptions);
    static create(options: SqsConsumerOptions): SqsConsumer;
    start(): void;
    stop(): void;
    on(event: string | symbol, handler: (...args: any) => void): void;
    private poll;
    private isConnError;
    private handleSqsResponse;
    private processMessage;
    private getMessagePayload;
    private parseMessagePayload;
    private receiveMessages;
    private deleteMessage;
}
export {};
